Functions
- load_
page_ fonts - Load all fonts referenced by a page into a FontCache.
- load_
single_ font - load_
single_ font_ dict - Load a font from its (already-resolved) font dictionary. Used both by
load_single_fontand for inline font dicts in form resources (e.g. a synthesized field appearance referencing a standard Helvetica).