ByteRangeCoverage

Struct ByteRangeCoverage 

pub struct ByteRangeCoverage {
    pub ranges: Vec<(usize, usize)>,
    pub covers_whole_document: bool,
    pub bytes_after_signature: usize,
}
How a signature’s /ByteRange covers the file.

Fields

ranges: Vec<(usize, usize)>

The (offset, length) spans of the file that are signed, in order.

covers_whole_document: bool

True when the ranges start at byte 0 and the last range ends exactly at end-of-file (the single gap being the /Contents placeholder) — i.e. the signature covers the whole document.

bytes_after_signature: usize

Bytes present after the last signed span. Non-zero means the file was extended after this signature was applied — a later incremental update (possibly another signature, possibly a modification the signature does not cover).