pub fn generate_annotation_appearance(
file: &PdfFile,
dict: &PdfDict,
subtype: &str,
rect: Rect,
) -> Option<GeneratedAppearance>Expand description
Build a generated appearance for a markup / geometric annotation that has no
/AP, or None when the subtype is unsupported or nothing should be drawn.
dict is the annotation dictionary and rect its /Rect.